@@ -1,6 +1,7 @@
-# $Id: iTunes.pm 2218 2007-03-18 15:54:56Z comdog $
+# $Id: iTunes.pm 2634 2008-08-06 12:58:30Z comdog $
 package Mac::iTunes;
 use strict;
+use warnings;
 
 use base qw(Exporter);
 use vars qw($VERSION);
@@ -11,7 +12,7 @@ use Mac::iTunes::Playlist;
 
 require Exporter;
 
-$VERSION = '0.89';
+$VERSION = '0.90';
 
 =head1 NAME
 
@@ -311,7 +312,7 @@ Mac OS X
 =head1 SOURCE AVAILABILITY
 
 This source is part of a SourceForge project which always has the
-latest sources in CVS, as well as all of the previous releases.
+latest sources in SVN, as well as all of the previous releases.
 
 	http://sourceforge.net/projects/brian-d-foy/
 
@@ -324,7 +325,7 @@ brian d foy,  C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2007 brian d foy.  All rights reserved.
+Copyright (c) 2002-2008 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
